package com.knauf.ejb.kuchen;

import java.util.logging.Logger;

import javax.ejb.CreateException;
import javax.ejb.FinderException;

/**
 * Abstrakte Bean-Klasse fr ein Objekt "Kuchen". Sie hat genau ein weiteres
 * Feld: "Kuchen-Name". Die ID wird per Select-Methode erzeugt.
 * 
 * @author Wolfgang Knauf
 */
public abstract class KuchenSingleBean implements javax.ejb.EntityBean {
  private static final Logger logger = Logger.getLogger(KuchenSingleBean.class.getName());

  private javax.ejb.EntityContext myEntityCtx;

  /**
   * setEntityContext
   */
  public void setEntityContext(javax.ejb.EntityContext ctx)
  {
    myEntityCtx = ctx;
  }

  /**
   * getEntityContext
   */
  public javax.ejb.EntityContext getEntityContext()
  {
    return myEntityCtx;
  }

  /**
   * unsetEntityContext
   */
  public void unsetEntityContext()
  {
    myEntityCtx = null;
  }


  /**Bean wird aktiviert.
   * 
   */
  public void ejbActivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbActivate");
  }

  /**Bean wird geladen.
   * 
   */
  public void ejbLoad() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbLoad");
  }

  /**Bean wird deaktiviert/passiviert.
   * 
   */
  public void ejbPassivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbPassivate");
  }

  /**Bean wird gelscht.
   * 
   */
  public void ejbRemove() throws javax.ejb.RemoveException, javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbRemove");
  }

  /**Bean wird gespeichert.
   * 
   */
  public void ejbStore() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbStore");
  }

  /**
   * Get accessor for persistent attribute: id
   */
  public abstract java.lang.Integer getId();

  /**
   * Set accessor for persistent attribute: id
   */
  public abstract void setId(java.lang.Integer newId);

  /**
   * Get accessor for persistent attribute: name
   */
  public abstract java.lang.String getName();

  /**
   * Set accessor for persistent attribute: name
   */
  public abstract void setName(java.lang.String newName);

  /**
   * ejbCreate
   */
  public java.lang.Integer ejbCreate() throws javax.ejb.CreateException
  {
    //Die ID erzeugen wir hier manuell:
    try
    {
      //Per ejbSelect die bisher maximal vergebene Id holen:
      Integer intId =this.ejbSelectMaxId();
      //Wenn Datenbank leer kommt hier NULL zurck ! Wenn vorhanden um 1 erhhen.
      if (intId == null)
        intId = new Integer (100);
      else
        intId = new Integer (intId.intValue() + 1);
      setId(intId );
    }
    catch (FinderException fex)
    {
      throw new CreateException ("Erzeugung des Kuchens schlug fehl: Holen der NextId per ejbSelectMaxId erzeugte eine FinderException: " + fex.getMessage() );
    }
    return null;
  }

  /**
   * Erzeugen eines Kuchen-Objekts, wobei der Name angegeben wird. Der Key
   * automatisch erzeugt.
   * 
   * @param str_Name
   *          Der Name des Kuchens.
   * @return Immer NULL.
   * @exception CreateException
   *              Fehler beim Erzeugen.
   */
  public java.lang.Integer ejbCreateByName(String str_Name) throws javax.ejb.CreateException
  {
    this.setName(str_Name);
    //Die ID erzeugen wir hier manuell:
    try
    {
      //Per ejbSelect die bisher maximal vergebene Id holen:
      Integer intId =this.ejbSelectMaxId();
      //Wenn Datenbank leer kommt hier NULL zurck ! Wenn vorhanden um 1 erhhen.
      if (intId == null)
        intId = new Integer (100);
      else
        intId = new Integer (intId.intValue() + 1);
      setId(intId );
    }
    catch (FinderException fex)
    {
      throw new CreateException ("Erzeugung des Kuchens schlug fehl: Holen der NextId per ejbSelectMaxId erzeugte eine FinderException: " + fex.getMessage() );
    }
    
    return null;
  }

  /**
   * ejbPostCreate
   */
  public void ejbPostCreate() throws javax.ejb.CreateException
  {
  }

  /**
   * Nach dem Erzeugen eines Kuchen-Objekts, wobei der Name angegeben wird:
   * nichts besonderes zu tun.
   * 
   * @param str_Name
   *          Der Name des Kuchens.
   * @exception CreateException
   *              Fehler beim Erzeugen.
   */
  public void ejbPostCreateByName(String str_Name) throws javax.ejb.CreateException
  {
  }
  
  /**Select-Methode fr das Ermitteln der bisherigen maximalen ID in der Datenbank.
   * 
   * @return Die maximale Kuchen-ID aus der Datenbank, oder NULL bei leerer DB.
   * @throws javax.ejb.FinderException
   */
  public abstract java.lang.Integer ejbSelectMaxId() throws javax.ejb.FinderException;
}
